@@ -1,5 +1,6 @@
 from django.conf import settings
 from django.core.management.base import BaseCommand
+from django.db import DEFAULT_DB_ALIAS
 
 from django_pgviews.models import ViewSyncer
 
@@ -46,11 +47,16 @@ class Command(BaseCommand):
                 "if the SQL is different. By default uses django setting MATERIALIZED_VIEWS_CHECK_SQL_CHANGED."
             ),
         )
+        parser.add_argument(
+            "--database",
+            default=DEFAULT_DB_ALIAS,
+            help='Nominates a database to synchronize. Defaults to the "default" database.',
+        )
 
-    def handle(self, force, update, materialized_views_check_sql_changed, **options):
+    def handle(self, force, update, materialized_views_check_sql_changed, database, **options):
         vs = ViewSyncer()
 
         if materialized_views_check_sql_changed is None:
             materialized_views_check_sql_changed = getattr(settings, "MATERIALIZED_VIEWS_CHECK_SQL_CHANGED", False)
 
-        vs.run(force, update, materialized_views_check_sql_changed=materialized_views_check_sql_changed)
+        vs.run(force, update, using=database, materialized_views_check_sql_changed=materialized_views_check_sql_changed)
